@@ -17,11 +17,20 @@ This is the complete API reference:
    experiment_type
    dobject_biometa
    readout
+
+Tracking versions & migrations:
+
+.. autosummary::
+   :toctree: .
+
    version_vvhc
+   migration_vvhc
+
 """
 # This is lnschema-module vvhc.
-_schema_module_id = "vvhc"
-__version__ = "0.3.6"
+_schema = "vvhc"
+_migration = None
+__version__ = "0.4.0"
 _tables = ["biosample", "techsample"]
 
 from ._core import (  # noqa
@@ -29,6 +38,7 @@ from ._core import (  # noqa
     dobject_biometa,
     experiment,
     experiment_type,
+    migration_vvhc,
     project,
     readout,
     version_vvhc,
